from django.shortcuts import render
from django.contrib.contenttypes.models import ContentType
from django.views.generic import ListView
from django.conf import settings


class IndexView(ListView):
    model = ContentType
    template_name = "django-uptime/index.html"

    def get_queryset(self):
        ct_count = ContentType.objects.all().count()
        return ct_count

    def get_context_data(self, **kwargs):
        context = super(IndexView, self).get_context_data(**kwargs)
        return context



from setuptools import setup, find_packages

version = "0.2"


setup(
    name="django_uptime",
    version=version,
    description="Editable non-cached monitorization path for Django",
    long_description="""
    Editable non-cached monitorization path for Django. Standarized path for multiple django project moritorization
    """,
    classifiers=[
        "Programming Language :: Python :: 3",
        "Framework :: Django :: 1.11",
    ],
    keywords="moritorization,uptime",
    author="Urtzi",
    author_email="uodriozola@codesyntax.eus",
    url="https://github.com/codesyntax/django-uptime",
    license="MIT license",
    packages=find_packages(exclude=["ez_setup", "examples", "tests"]),
    include_package_data=True,
    zip_safe=False,
    install_requires=[
        "Django>=1.11",
    ],
    entry_points="""
      # -*- Entry points: -*-
      """,
)
